package tfg;

import org.jsfml.graphics.RenderWindow;
import org.jsfml.graphics.View;
import org.jsfml.system.Vector2f;
import org.jsfml.system.Vector2i;

/**
 * Camera that can center on various objects.
 * @author Ritchie Cunningham
 */
public class Camera {
    /**
     * The window the camera is affecting.
     */
    private RenderWindow window;

    /**
     * Default view.
     */
    private View defaultView;

    /**
     * Create a new camera for window w.
     * @param w Window for which to create the camera.
     */
    public Camera(RenderWindow w) {
        window = w;
        defaultView = (View) window.getDefaultView();
    }

    public void centerOn(AnimatedSprite s) {
        /* Copy the default view. */
        View newView = new View(defaultView.getCenter(), defaultView.getSize());
        Vector2f spritePos = s.getSprite().getPosition();
        Vector2i spriteSize = s.getSpriteSize();
        /* Convert the size to a float. */
        Vector2f newSpriteSize = new Vector2f(spriteSize.x, spriteSize.y);
        /* Divide the size in half (for centering). */
        newSpriteSize = Vector2f.div(newSpriteSize, 2);
        Vector2f cameraPos = Vector2f.add(spritePos, newSpriteSize);
        cameraPos = new Vector2f(Math.round(cameraPos.x), Math.round(cameraPos.y));
        newView.setCenter(cameraPos);
        window.setView(newView);
    }

    /**
     * Center the camera on the default view.
     */
    public void centerOnDefault() {
        window.setView(defaultView);
    }
}
