package tfg;

import org.jsfml.graphics.Color;
import org.jsfml.graphics.Drawable;
import org.jsfml.graphics.Font;
import org.jsfml.graphics.RenderStates;
import org.jsfml.graphics.RenderTarget;
import org.jsfml.graphics.Text;
import org.jsfml.graphics.TextStyle;

import java.io.IOException;
import java.nio.file.Paths;

/**
 * UI Elements containing a dynamic text label.
 * @author Ritchie Cunningham
 */
public class TextUIElement implements Drawable {
    /**
     * The font for the text.
     */
    private Font font = new Font();
    /**
     * The text object containing style and content.
     */
    private Text text = new Text();
    
    /**
     * Create a new Text UI Element with the specified options and a default style.
     * @param p Position on the screen to display the label.
     * @param c The Color to set the text.
     * @param size The size to render the text.
     */
    public TextUIElement(InterfacePosition p, Color c, int size) {
        this(p, c, size, TextStyle.REGULAR);
    }

    /**
     * Create a new Text UI element with the specified options and style.
     * @param p Position on the screen to display the label.
     * @param c Color to set the text.
     * @param size Size to render the text.
     * @param style Style to apply to the text.
     */
    public TextUIElement(InterfacePosition p, Color c, int size, int style) {
        /* Attempt to load font. */
        try {
            font.loadFromFile(Paths.get("res/kpixel.ttf"));
        } catch (IOException ex) {
            ex.printStackTrace();
        }

        text.setFont(font);             /* Apply the selected font. */
        text.setCharacterSize(size);    /* Update the character size. */
        text.setColor(c);               /* Change the color. */
        text.setStyle(style);           /* Set the desired style. */
        setPosition(p);                 /* Position the label. */
    }

    /**
     * Update the value of the text.
     * @param s New value for the text.
     */
    public void updateString(String s) {
        text.setString(s);
    }

    /**
     * Position the element on the screen.
     * @param p Position on screen.
     */
    public void setPosition(InterfacePosition p) {
        switch(p) {
            case TOP_LEFT:
                text.setPosition(0,0); /* Default (0,0) if pos is top left. */
                break;
            default:
                break;
        }
    }

    /**
     * Draw the UI elements to screen.
     */
    public void draw(RenderTarget target, RenderStates states) {
        text.draw(target, states);
    }
}
